# -*- coding: utf-8 -*-
VERSION = '1.3-7'

__version__ = VERSION
__author__ = "Kuba Janoszek"

# module public API
from .api import *  # noqa
